@@ -106,7 +106,7 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   mEffectRunning = false;
 
   mTimer.setSingleShot(true);
-  connect(&mTimer, SIGNAL(timeout()), SLOT(slotTimeout()));
+  connect(&mTimer, SIGNAL(timeout()), SLOT(update()));
   mTimer.start(10);
 
   QDesktopWidget *d = QApplication::desktop();
@@ -703,13 +703,6 @@ void kSlideShowSaver::restart()
 }
 
 
-//-----------------------------------------------------------------------------
-void kSlideShowSaver::slotTimeout()
-{
-  update();
-}
-
-
 //-----------------------------------------------------------------------------
 void kSlideShowSaver::paintEvent(QPaintEvent *)
 {
@@ -946,8 +939,7 @@ kSlideShowSetup::kSlideShowSetup(QWidget *aParent)
 
   QWidget *main = new QWidget(this);
   setMainWidget(main);
-  cfg = new SlideShowCfg();
-  cfg->setupUi( main );
+  cfg = new SlideShowCfg(main);
 
   cfg->mPreview->setFixedSize(220, 170);
   cfg->mPreview->show();    // otherwise saver does not get correct size
@@ -966,7 +958,6 @@ kSlideShowSetup::kSlideShowSetup(QWidget *aParent)
 kSlideShowSetup::~kSlideShowSetup()
 {
     delete mSaver;
-    delete cfg;
 }
 
 //-----------------------------------------------------------------------------
@@ -978,6 +969,7 @@ void kSlideShowSetup::readSettings()
     cfg->mCbxZoom->setChecked(config.readEntry("ZoomImages", false));
     cfg->mCbxShowName->setChecked(config.readEntry("PrintName", true));
     cfg->mDelay->setValue(config.readEntry("Delay", 20));
+    cfg->mDelay->setSuffix(ki18np(" second", " seconds"));
     cfg->mDirChooser->setPath(config.readPathEntry("Directory", QString()));
     cfg->mCbxSubdirectory->setChecked(config.readEntry("SubDirectory", false));
     cfg->mCbxRandomPosition->setChecked(config.readEntry("RandomPosition", false));
