@@ -1,17 +1,21 @@
+/*
+ *	Distributed under the terms of the BSD license.
+ */
+
 #ifndef __KDE_CDECONFIG_H
 #define __KDE_CDECONFIG_H
 
 #include <qcheckbox.h>
-#include <qgroupbox.h>
-#include <qbuttongroup.h>
+#include <q3groupbox.h>
+#include <q3buttongroup.h>
 #include <qlabel.h>
 #include <qradiobutton.h>
-#include <qhbox.h>
+#include <q3hbox.h>
 #include <kconfig.h>
 
 class QCheckBox;
-class QGroupBox;
-class QVBox;
+class Q3GroupBox;
+class KVBox;
 class QLabel;
 class QRadioButton;
 
@@ -40,9 +44,9 @@ class CdeConfig: public QObject
 		KConfig*   	cdeConfig;
 		QCheckBox* 	cbColorBorder;
 //		QCheckBox* 	cbTitlebarButton;
-		QHBox* 	        groupBox;
-		QGroupBox* 	gbSlider;
-		QButtonGroup*	bgAlign;
+		KHBox* 	        groupBox;
+		Q3GroupBox* 	gbSlider;
+		Q3ButtonGroup*	bgAlign;
 };
 
 
