@@ -17,15 +17,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QStyle>
 #include <QPainter>
-//#include <qdatetime.h>
-//#include <qdrawutil.h>
-//#include <qlayout.h>
-//#include <qpainter.h>
-//#include <qbitmap.h>
-//#include <qlabel.h>
-//#include <qtooltip.h>
-
-//Added by qt3to4:
 #include <QBoxLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
@@ -37,7 +28,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <kpixmapeffect.h>
 
 namespace KStep {
 
@@ -210,6 +200,30 @@ static inline const KDecorationOptions* options()
     return KDecoration::options();
 }
 
+static void verticalGradient(QPixmap *pix, QColor first, QColor second)
+{
+    QLinearGradient gradient(0, 0, 0, pix->height());
+    gradient.setColorAt(0.0, first);
+    gradient.setColorAt(1.0, second);
+    QBrush brush(gradient);
+    QPainter p;
+    p.begin(pix);
+    p.fillRect(pix->rect(), brush);
+    p.end();
+}
+
+static void diagonalGradient(QPixmap *pix, QColor first, QColor second)
+{
+    QLinearGradient gradient(0, 0, pix->width(), pix->height());
+    gradient.setColorAt(0.0, first);
+    gradient.setColorAt(1.0, second);
+    QBrush brush(gradient);
+    QPainter p;
+    p.begin(pix);
+    p.fillRect(pix->rect(), brush);
+    p.end();
+}
+
 static void create_pixmaps(NextClientFactory *f)
 {
     if(pixmaps_created)
@@ -225,39 +239,35 @@ static void create_pixmaps(NextClientFactory *f)
     titleHeight &= ~1; // Make title height even
     if (titleHeight < 16) titleHeight = 16;
 
-    aTitlePix = new QPixmap(32, titleHeight - 2);
-    KPixmapEffect::gradient(*aTitlePix,
-                            options()->color(KDecoration::ColorTitleBar, true),
-                            options()->color(KDecoration::ColorTitleBlend, true),
-                            KPixmapEffect::VerticalGradient);
+    const int gradientHeight = titleHeight - 2;
+    aTitlePix = new QPixmap(32, gradientHeight);
+
+    verticalGradient(aTitlePix,
+	    options()->color(KDecoration::ColorTitleBar, true),
+	    options()->color(KDecoration::ColorTitleBlend, true));
     iTitlePix = new QPixmap(32, titleHeight - 2);
-    KPixmapEffect::gradient(*iTitlePix,
-                            options()->color(KDecoration::ColorTitleBar, false),
-                            options()->color(KDecoration::ColorTitleBlend, false),
-                            KPixmapEffect::VerticalGradient);
+    
+    verticalGradient(iTitlePix,
+	    options()->color(KDecoration::ColorTitleBar, false),
+	    options()->color(KDecoration::ColorTitleBlend, false));
     // Bottom frame gradient
     aFramePix = new QPixmap(32, handleSize);
-    KPixmapEffect::gradient(*aFramePix,
-                            options()->color(KDecoration::ColorFrame, true).light(150),
-                            options()->color(KDecoration::ColorFrame, true).dark(120),
-                            KPixmapEffect::VerticalGradient);
+    verticalGradient(aFramePix,
+	    options()->color(KDecoration::ColorFrame, true).light(150),
+	    options()->color(KDecoration::ColorFrame, true).dark(120));
     iFramePix = new QPixmap(32, handleSize);
-    KPixmapEffect::gradient(*iFramePix,
-                            options()->color(KDecoration::ColorFrame, false).light(150),
-                            options()->color(KDecoration::ColorFrame, false).dark(120),
-                            KPixmapEffect::VerticalGradient);
-
+    verticalGradient(iFramePix,
+	    options()->color(KDecoration::ColorFrame, false).light(150),
+	    options()->color(KDecoration::ColorFrame, false).dark(120));
     // Handle gradient
     aHandlePix = new QPixmap(32, handleSize);
-    KPixmapEffect::gradient(*aHandlePix,
-                            options()->color(KDecoration::ColorHandle, true).light(150),
-                            options()->color(KDecoration::ColorHandle, true).dark(120),
-                            KPixmapEffect::VerticalGradient);
+    verticalGradient(aHandlePix,
+	    options()->color(KDecoration::ColorHandle, true).light(150),
+	    options()->color(KDecoration::ColorHandle, true).dark(120));
     iHandlePix = new QPixmap(32, handleSize);
-    KPixmapEffect::gradient(*iHandlePix,
-                            options()->color(KDecoration::ColorHandle, false).light(150),
-                            options()->color(KDecoration::ColorHandle, false).dark(120),
-                            KPixmapEffect::VerticalGradient);
+    verticalGradient(iHandlePix,
+	    options()->color(KDecoration::ColorHandle, true).light(150),
+	    options()->color(KDecoration::ColorHandle, true).dark(120));
 
     int btnWidth = titleHeight;
     iBtn = new QPixmap(btnWidth, btnWidth);
@@ -273,20 +283,16 @@ static void create_pixmaps(NextClientFactory *f)
 
     // inactive buttons
     QColor c(options()->color(KDecoration::ColorButtonBg, false));
-    KPixmapEffect::gradient(*iBtn, c.light(120), c.dark(120),
-                            KPixmapEffect::DiagonalGradient);
-    KPixmapEffect::gradient(internal, c.dark(120), c.light(120),
-                            KPixmapEffect::DiagonalGradient);
+    diagonalGradient(iBtn, c.light(120), c.dark(120));
+    diagonalGradient(&internal, c.dark(120), c.light(120));
     p.begin(iBtn);
     p.drawPixmap(dest, internal, internal.rect());
     p.end();
     //bitBlt(iBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
 
 
-    KPixmapEffect::gradient(*iBtnDown, c.dark(120), c.light(120),
-                            KPixmapEffect::DiagonalGradient);
-    KPixmapEffect::gradient(internal, c.light(120), c.dark(120),
-                            KPixmapEffect::DiagonalGradient);
+    diagonalGradient(iBtnDown, c.dark(120), c.light(120));
+    diagonalGradient(&internal, c.light(120), c.dark(120));
     //bitBlt(iBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
     p.begin(iBtnDown);
     dest.moveTo(3, 3);
@@ -295,19 +301,15 @@ static void create_pixmaps(NextClientFactory *f)
 
     // active buttons
     c = options()->color(KDecoration::ColorButtonBg, true);
-    KPixmapEffect::gradient(*aBtn, c.light(120), c.dark(120),
-                            KPixmapEffect::DiagonalGradient);
-    KPixmapEffect::gradient(internal, c.dark(120), c.light(120),
-                            KPixmapEffect::DiagonalGradient);
+    diagonalGradient(aBtn, c.light(120), c.dark(120));
+    diagonalGradient(&internal, c.dark(120), c.light(120));
     //bitBlt(aBtn, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
     p.begin(aBtn);
     p.drawPixmap(dest, internal, internal.rect());
     p.end();
 
-    KPixmapEffect::gradient(*aBtnDown, c.dark(120), c.light(120),
-                            KPixmapEffect::DiagonalGradient);
-    KPixmapEffect::gradient(internal, c.light(120), c.dark(120),
-                            KPixmapEffect::DiagonalGradient);
+    diagonalGradient(aBtnDown, c.dark(120), c.light(120));
+    diagonalGradient(&internal, c.light(120), c.dark(120));
     //bitBlt(aBtnDown, 3, 3, &internal, 0, 0, internalHeight, internalHeight, Qt::CopyROP, true);
     p.begin(aBtnDown);
     p.drawPixmap(dest, internal, internal.rect());
@@ -446,11 +448,11 @@ void NextClient::init()
     //widget()->setBackgroundMode( NoBackground );
 
     QVBoxLayout *mainLayout = new QVBoxLayout(widget());
+    QBoxLayout *titleLayout = new QBoxLayout(QBoxLayout::LeftToRight);
+    QHBoxLayout *windowLayout = new QHBoxLayout();
     mainLayout->setMargin(0);
-    QBoxLayout  *titleLayout = new QBoxLayout(QBoxLayout::LeftToRight);
     titleLayout->setMargin(0);
     titleLayout->setSpacing(0);
-    QHBoxLayout *windowLayout = new QHBoxLayout();
     mainLayout->addLayout(titleLayout);
     mainLayout->addLayout(windowLayout, 1);
     mainLayout->addSpacing(mustDrawHandle() ? handleSize : 1);
@@ -506,7 +508,7 @@ void NextClient::initializeButtonsAndTitlebar(QBoxLayout* titleLayout)
     addButtons(titleLayout, right);
 
     // Finally, activate all live buttons
-    for ( int i = 0; i < MAX_NUM_BUTTONS; i++) {
+    for (int i = 0; i < MAX_NUM_BUTTONS; i++) {
         if (button[i]) {
             button[i]->setMouseTracking( TRUE );
         }
@@ -518,7 +520,7 @@ void NextClient::initializeButtonsAndTitlebar(QBoxLayout* titleLayout)
  * titleButtonsLeft and titleBUttonsRight. */
 void NextClient::addButtons(QBoxLayout* titleLayout, const QString& spec)
 {
-    for (unsigned int i=0; i<spec.length(); i++) {
+    for (int i = 0; i < spec.length(); i++) {
         switch (spec[i].toLatin1()) {
         case 'A':
             if (isMaximizable()) {
@@ -940,6 +942,9 @@ bool NextClient::eventFilter(QObject *o, QEvent *e)
 
 bool NextClient::drawbound(const QRect& geom, bool /* clear */)
 {
+    // Let kwin draw the bounds, for now.
+    return false;
+#if 0
     QPainter p(workspaceWidget());
     p.setPen(QPen(Qt::white, 3));
     p.setCompositionMode(QPainter::CompositionMode_Xor);
@@ -952,6 +957,7 @@ bool NextClient::drawbound(const QRect& geom, bool /* clear */)
 		geom.width() - 4, 3, Qt::white);
     }
     return true;
+#endif
 }
 
 // =====================================
@@ -981,7 +987,7 @@ bool NextClientFactory::reset(unsigned long /*changed*/)
     return true;
 }
 
-bool NextClientFactory::supports( Ability ability )
+bool NextClientFactory::supports( Ability ability ) const
 {
     switch( ability )
     {
