@@ -1,6 +1,6 @@
 /*
   RISC OS KWin client
-  
+
   Copyright 2000
     Rik Hemsley <rik@kde.org>
 
@@ -23,7 +23,16 @@
 #ifndef RISC_OS_MANAGER_H
 #define RISC_OS_MANAGER_H
 
-#include <qdict.h>
+#include <q3dict.h>
+//Added by qt3to4:
+#include <QMouseEvent>
+#include <QPixmap>
+#include <QVBoxLayout>
+#include <QResizeEvent>
+#include <QEvent>
+#include <QPaintEvent>
+#include <QBoxLayout>
+#include <Q3PtrList>
 #include <kdecoration.h>
 #include <kdecorationfactory.h>
 
@@ -73,7 +82,7 @@ class Manager : public KDecoration
 
       void slotAbove();
       void slotLower();
-      void slotMaximizeClicked(ButtonState);
+      void slotMaximizeClicked(Qt::MouseButton);
       void slotToggleSticky();
 
    protected:
@@ -85,7 +94,6 @@ class Manager : public KDecoration
       void paintEvent(QPaintEvent *);
       void resizeEvent(QResizeEvent *);
       void mouseDoubleClickEvent(QMouseEvent *);
-      void wheelEvent(QWheelEvent *e);
       bool animateMinimize(bool);
       void updateButtonVisibility();
       void updateTitleBuffer();
@@ -100,8 +108,8 @@ class Manager : public KDecoration
       QSpacerItem       *titleSpacer_;
 
       QPixmap           titleBuf_;
-      QPtrList<Button>  leftButtonList_;
-      QPtrList<Button>  rightButtonList_;
+      Q3PtrList<Button>  leftButtonList_;
+      Q3PtrList<Button>  rightButtonList_;
 };
 
 class Factory : public QObject, public KDecorationFactory
