@@ -29,12 +29,12 @@ PhaseStyleConfig::PhaseStyleConfig(QWidget* parent) : QWidget(parent)
 
     setupUi(this);
 
-    QSettings settings;
+    QSettings settings("phasestyle");
     oldgradients =
-        settings.value("/phasestyle/Settings/gradients", true).toBool();
+        settings.value("/gradients", true).toBool();
     gradients->setChecked(oldgradients);
     oldhighlights =
-        settings.value("/phasestyle/Settings/highlights", true).toBool();
+        settings.value("/highlights", true).toBool();
     highlights->setChecked(oldhighlights);
 
     // connections
@@ -78,11 +78,9 @@ void PhaseStyleConfig::updateChanged()
 
 void PhaseStyleConfig::save()
 {
-    QSettings settings;
-    settings.setValue("/phasestyle/Settings/gradients",
-                      gradients->isChecked());
-    settings.setValue("/phasestyle/Settings/highlights",
-                      highlights->isChecked());
+    QSettings settings("phasestyle");
+    settings.setValue("/gradients", gradients->isChecked());
+    settings.setValue("/highlights", highlights->isChecked());
 }
 
 //////////////////////////////////////////////////////////////////////////////
